@@ -26,7 +26,6 @@ from lxml.html.soupparser import parse
 from django.core.management.base import BaseCommand
 from django.conf import settings
 from django.template.loader import get_template
-from django.template import Context
 from BeautifulSoup import (
         BeautifulSoup, Tag, Comment, ProcessingInstruction, NavigableString,
         Declaration, CData)
@@ -504,28 +503,10 @@ class Command(BaseCommand):
             analyticsComment = etree.Comment(
                 text=get_template(
                     'boilerplate/txt/AnalyticsComment.txt').render())
-
-            # iframe
-            analyticsIframe = etree.Element('iframe')
-            url = get_template(
-                    'boilerplate/txt/AnalyticsUrl.txt').render()
-            analyticUrl = \
-                "%s?upc=%s&complexity=CMS_PLUGINIZE_REPLACE" % (url, upc)
-
-            analyticsIframe.set('src', analyticUrl)
-            analyticsIframe.set('name', "_themes_tracking")
-            analyticsIframe.set('width', "1")
-            analyticsIframe.set('height', "1")
-            analyticsIframe.set('marginwidth', "0")
-            analyticsIframe.set('marginheight', "0")
-            analyticsIframe.set('align', "top")
-            analyticsIframe.set('scrolling', "No")
-            analyticsIframe.set('frameborder', "0")
-            analyticsIframe.set('hspace', "0")
-            analyticsIframe.set('vspace', "0")
+            includeHtml = etree.Comment("### include _tracking.html ###")
 
             body.append(analyticsComment)
-            body.append(analyticsIframe)
+            body.append(includeHtml)
 
         # add header legel
         html = page.getroot()
