@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_zip.py 10574 2017-11-29 03:26:17Z Lavender $
+# $Id: create_zip.py 10579 2017-11-29 06:00:34Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-11-29 11:26:17 +0800 (週三, 29 十一月 2017) $
-# $Revision: 10574 $
+# $Date: 2017-11-29 14:00:34 +0800 (週三, 29 十一月 2017) $
+# $Revision: 10579 $
 
 import os
 import shutil
@@ -53,6 +53,9 @@ class Command(BaseCommand):
             with open(os.path.join(ROOT_DIR_PATH, 'info.json')) as jsonfile:
                 data = json.load(jsonfile)
 
+            upc = data['upc']
+            complexity = data['complexity']
+
             content = ''
             for root, dirs, files in os.walk(TEMPLATES_DIR_PATH):
                 for temp in files:
@@ -60,25 +63,26 @@ class Command(BaseCommand):
                         htmlContent = f.read()
                     htmlContent = htmlContent.replace(
                         "<!--### include _tracking.html ###-->",
-                        "{% include '_tracking.html' %}")
+                        ("{% include '_tracking.html' with upc='" + upc +
+                         "' complexity='" + str(complexity) + "' %}")) 
                     with open(os.path.join(root, temp), 'wb') as f:
                         f.write(htmlContent.encode('utf8'))
                     content += htmlContent
             data['checksum'] = hashlib.md5(content).hexdigest()
 
-            upc = data['upc']
-            complexity = data['complexity']
-
             with open(os.path.join(ROOT_DIR_PATH, 'info.json'), 'w') as f:
                 line = json.dumps(data)
                 f.write(line)
 
-            context = Context({'upc': upc, 'complexity': complexity})
             temp = get_template('boilerplate/html/Tracking.html')
-            content = temp.render(context)
+            content = temp.render()
             with open(os.path.join(
                 TEMPLATES_DIR_PATH, '_tracking.html'), 'wb') as f:
                 f.write(content.encode('utf8'))
+            with open(os.path.join(
+                ROOT_DIR_PATH, 'MANIFAST.INFO'), 'wb') as f:
+                manifast = json.dumps({'upc': upc, 'complexity': complexity})
+                f.write(manifast.encode('utf8'))
                 
         templateName = options['templateName']
 
@@ -108,12 +112,8 @@ class Command(BaseCommand):
                 logger.info("Zip " + path)
                 zip.write(path)
 
-        if os.path.isfile(os.path.join(ROOT_DIR_PATH, 'info.json')):
-            context = Context({'upc': upc,})
-        else:
-            context = Context({'upc': None,})
         temp = get_template('boilerplate/py/setup.py')
-        content = temp.render(context)
+        content = temp.render()
         with open(os.path.join(ROOT_DIR_PATH, 'setup.py'), 'wb') as f:
             f.write(content.encode('utf8'))
             
@@ -128,6 +128,10 @@ class Command(BaseCommand):
         zip.write('./setup.py')
         logger.info("Zip setup.py")
 
+        if os.path.isfile(os.path.join(ROOT_DIR_PATH, 'info.json')):
+            zip.write('MANIFAST.INFO')
+            logger.info("Zip MANIFAST.INFO")
+            
         zip.close()
 
         dst = options['path']
@@ -164,6 +168,8 @@ class Command(BaseCommand):
             os.remove('./setup.py')
         if os.path.isfile('./info.json'):
             os.remove('./info.json')
+        if os.path.isfile('./MANIFAST.INFO'):
+            os.remove('./MANIFAST.INFO')
         if os.path.isfile('./%s.zip' % templateName):
             os.remove('./%s.zip' % templateName)
         
