@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: fix_template.py 10389 2017-10-22 05:43:34Z Lavender $
+# $Id: fix_template.py 10574 2017-11-29 03:26:17Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-10-22 13:43:34 +0800 (Sun, 22 Oct 2017) $
-# $Revision: 10389 $
+# $Date: 2017-11-29 11:26:17 +0800 (週三, 29 十一月 2017) $
+# $Revision: 10574 $
 
 import os
 import hashlib
@@ -57,8 +57,7 @@ class Command(BaseCommand):
             with open(htmlfile, 'rb') as f:
                 text = f.read()
                 text = text.replace(
-                    "{% load cms_tags menu_tags sekizai_tags %}"
-                    "{% load staticfiles %}", 
+                    "{% load cms_tags menu_tags sekizai_tags staticfiles %}", 
                     "{% load FakeTemplateTags %}" + loadTagHash)
                 text = text.replace("{% render_block 'css' %}", cssHash)
                 text = text.replace("{% render_block 'js' %}", jsHash)
@@ -84,12 +83,10 @@ class Command(BaseCommand):
             # endprocess
             text = text.replace(
                 loadTagHash, 
-                "{% load cms_tags menu_tags sekizai_tags %}"
-                "{% load staticfiles %}")
+                "{% load cms_tags menu_tags sekizai_tags staticfiles %}")
             text = text.replace(jsHash, "{% render_block 'js' %}")
             text = text.replace(cssHash, "{% render_block 'css' %}")
             text = text.replace(toolbarHash, "{% cms_toolbar %}")
             with open(fileName, 'wb') as f:
                 f.write(text.encode('utf8'))
-            
-        
\ No newline at end of file
+            
\ No newline at end of file
